@@ -346,6 +346,22 @@ class MyWhatify:
         func = switcher.get(method.upper(), lambda: "Invalid api method")
         return func(url=url, headers=headers, body=body, params=params, user_token=user_token)
 
+    @classmethod
+    def test_api(cls, url, method, expected_response, headers=None, body=None, params=None, user_token=None):
+        expected_payload, expected_status_code = expected_response
+
+        with allure.step('checking endpoint (url): ' + str(url)):
+            print(url)
+
+        with allure.step('sending the API with method: ' + str(method)):
+            response = cls.send_api(url=url, method=method, headers=headers, body=body, params=params, user_token=user_token)
+
+        with allure.step('validating the expected response'):
+            assert response.status_code == expected_status_code, f"Status code is not as expected: {response.status_code} instead of {expected_status_code}"
+
+        with allure.step('validating response json'):
+            assert str(expected_payload) == str(response), f"Response is not as expected: {response}, instead of {expected_payload}"
+
     @classmethod
     def get_data_source(cls, data_name):
         logging.info('getting the DataSource list for data_name: ' + str(data_name))
